@@ -14,8 +14,8 @@ def upsert(engine,
            table_name,
            if_row_exists,
            schema=None,
-           create_schema=True,
-           add_new_columns=True,
+           create_schema=False,
+           add_new_columns=False,
            adapt_dtype_of_empty_db_columns=False,
            chunksize=10000,
            dtype=None):
@@ -23,8 +23,9 @@ def upsert(engine,
     Insert updates/ignores a pandas DataFrame into a SQL table (or
     creates a SQL table from the DataFrame if it does not exist).
 
-    This index of the DataFrame must be the primary key of the
-    SQL table and meet the following conditions:
+    This index of the DataFrame must be the primary key or a unique key
+    (can be a unique constraint with multiple columns too) of the SQL
+    table and meet the following conditions:
     1. The index must be unique.
     2. All levels of the index have to be named.
     3. The index cannot contain any null value except for MySQL where
@@ -53,12 +54,12 @@ def upsert(engine,
     if_row_exists : {'ignore', 'update'}
         Behavior if a row exists in the SQL table.
         Irrelevant if the SQL table does not exist already.
-        For both 'ignore' and 'update' rows with new primary
+        For both 'ignore' and 'update' rows with new primary/unique
         key values are inserted.
 
-        * 'ignore': rows for which primary keys exist in the SQL
+        * 'ignore': rows for which primary/unique keys exist in the SQL
         table are skipped
-        * 'update': rows for which primary keys exist in the SQL
+        * 'update': rows for which primary/unique keys exist in the SQL
         table are updated (with the columns available in the pandas
         DataFrame)
     schema : str or None, default None
@@ -66,9 +67,9 @@ def upsert(engine,
         For postgres if it is None it will default to "public".
         For MySQL and SQlite the schema should be None since
         those SQL flavors do not have this system.
-    create_schema : bool, default True
+    create_schema : bool, default False
         If True the schema is created if it does not exist
-    add_new_columns : bool, default True
+    add_new_columns : bool, default False
         If True adds columns present in the DataFrame that
         are not in the SQL table.
     adapt_dtype_of_empty_db_columns : bool, default False
@@ -202,43 +203,3 @@ def upsert(engine,
     if df.empty:
         return
     pse.upsert(if_row_exists=if_row_exists, chunksize=chunksize)
-
-
-# # pg_upsert - DEPRECATED
-
-def pg_upsert(**kwargs):
-    """
-    **DEPRECATED**
-    
-    Kept for compatibility with the previous version.
-    Will be deleted in the next version.
-    """
-    # issue deprecation
-    warnings.warn(("pangres.pg_upsert is deprecated and will be deleted in the "
-                   "next version of pangres, please use pangres.upsert instead!!"),
-                  FutureWarning)
-    # check arguments
-    required = set(('engine', 'df', 'table_name', 'if_exists'))
-    optional = set(('schema', 'create_schema', 'add_new_columns',
-                    'adapt_dtype_of_empty_db_columns', 'chunksize',
-                    'clean_column_names'))
-    missing = required - set(kwargs.keys())
-    if missing != set():
-        raise ValueError(f'Some required arguments are missing: {missing}')
-    # disgard any additional kwarg
-    kwargs = {k:v for k, v in kwargs.items() if k in required or k in optional}
-    # clean column names for postgres like we used to
-    clean_column_names = kwargs.pop('clean_column_names', False)
-    if clean_column_names:
-        from pangres import fix_psycopg2_bad_cols
-        kwargs['df'] = fix_psycopg2_bad_cols(kwargs['df'])
-    # convert argument if_exists we used in the previous version
-    kwargs['if_row_exists'] = kwargs.pop('if_exists')
-    if kwargs['if_row_exists'] == 'upsert_overwrite':
-        kwargs['if_row_exists'] = 'update'
-    elif kwargs['if_row_exists'] == 'upsert_keep':
-        kwargs['if_row_exists'] = 'ignore'
-    else:
-        raise ValueError('if_exists must be either "upsert_overwrite" or "upsert_keep"')
-    # upsert
-    upsert(**kwargs)
